@@ -677,7 +677,7 @@ def build_client(db_config: DBConfig) -> str:
     return f"""
 client = create_async_client(
     dsn={db_config.dsn_str()},
-    tls_security={add_quotes_to_non_env_vars(db_config.tls_security.value)},
+    tls_security={add_quotes_to_non_env_vars(db_config.tls_security.value)}
 )
     """
 
